@@ -1,6 +1,6 @@
 /*
  * dhcpcd - DHCP client daemon
- * Copyright (c) 2006-2018 Roy Marples <roy@marples.name>
+ * Copyright (c) 2006-2019 Roy Marples <roy@marples.name>
  * All rights reserved
 
  * Redistribution and use in source and binary forms, with or without
@@ -140,10 +140,15 @@ hwaddr_aton(uint8_t *buffer, const char *addr)
 	size_t len = 0;
 
 	c[2] = '\0';
-	while (*p) {
+	while (*p != '\0') {
+		/* Skip separators */
 		c[0] = *p++;
-		if (c[0] == '\n')
+		switch (c[0]) {
+		case '\n':	/* long duid split on lines */
+		case ':':	/* typical mac address */
+		case '-':	/* uuid */
 			continue;
+		}
 		c[1] = *p++;
 		/* Ensure that digits are hex */
 		if (isxdigit((unsigned char)c[0]) == 0 ||
@@ -157,15 +162,6 @@ hwaddr_aton(uint8_t *buffer, const char *addr)
 			errno = EINVAL;
 			return 0;
 		}
-		/* Ensure that next data is EOL or a seperator with data */
-		if (!(*p == '\0' || *p == '\n' ||
-		    (*p == ':' && *(p + 1) != '\0')))
-		{
-			errno = EINVAL;
-			return 0;
-		}
-		if (*p)
-			p++;
 		if (bp)
 			*bp++ = (uint8_t)strtol(c, NULL, 16);
 		len++;
@@ -204,51 +200,3 @@ read_hwaddr_aton(uint8_t **data, const char *path)
 	fclose(fp);
 	return len;
 }
-
-ssize_t
-recvmsg_realloc(int fd, struct msghdr *msg, int flags)
-{
-	struct iovec *iov;
-	ssize_t slen;
-	size_t len;
-	void *n;
-
-	assert(msg != NULL);
-	assert(msg->msg_iov != NULL && msg->msg_iovlen > 0);
-	assert((flags & (MSG_PEEK | MSG_TRUNC)) == 0);
-
-	/* Assume we are reallocing the last iovec. */
-	iov = &msg->msg_iov[msg->msg_iovlen - 1];
-
-	for (;;) {
-		/* Passing MSG_TRUNC should return the actual size needed. */
-		slen = recvmsg(fd, msg, flags | MSG_PEEK | MSG_TRUNC);
-		if (slen == -1)
-			return -1;
-		if (!(msg->msg_flags & MSG_TRUNC))
-			break;
-
-		len = (size_t)slen;
-
-		/* Some kernels return the size of the receive buffer
-		 * on truncation, not the actual size needed.
-		 * So grow the buffer and try again. */
-		if (iov->iov_len == len)
-			len++;
-		else if (iov->iov_len > len)
-			break;
-		len = roundup(len, IOVEC_BUFSIZ);
-		if ((n = realloc(iov->iov_base, len)) == NULL)
-			return -1;
-		iov->iov_base = n;
-		iov->iov_len = len;
-	}
-
-	slen = recvmsg(fd, msg, flags);
-	if (slen != -1 && msg->msg_flags & MSG_TRUNC) {
-		/* This should not be possible ... */
-		errno = ENOBUFS;
-		return -1;
-	}
-	return slen;
-}
