@@ -1078,7 +1078,9 @@ if_handlelink(struct dhcpcd_ctx *ctx)
 		return -1;
 	if (len == 0)
 		return 0;
-	if (len < rtm.hdr.rtm_msglen) {
+	if ((size_t)len < offsetof(struct rt_msghdr, rtm_index) ||
+	    len < rtm.hdr.rtm_msglen)
+	{
 		errno = EINVAL;
 		return -1;
 	}
